# Fedora package release versions are committed as versions in upstream
%define origrel 1

# Tests currently fail, so tests are disabled for now
# See https://github.com/xsuchy/rpmconf/issues/31
%bcond_with tests

Name:           rpmconf
Summary:        Tool to handle rpmnew and rpmsave files
Group:          System/Packaging
License:        GPLv3
Version:        1.0.16
Release:        %mkrel 1
URL:            http://wiki.github.com/xsuchy/rpmconf
Source0:        https://github.com/xsuchy/rpmconf/archive/%{name}-%{version}-%{origrel}.tar.gz
BuildArch:      noarch
BuildRequires:  docbook-utils
BuildRequires:  docbook-dtd31-sgml
BuildRequires:  python3-sphinx
BuildRequires:  python3-devel
BuildRequires:  python3-rpm

%if %{with tests}
BuildRequires:  python3-pylint
BuildRequires:  python3-six
%endif

Requires:       %{name}-base
Requires:       python3-%{name}
Requires:       python3-rpm

# mergetools
Suggests: diffuse 
Suggests: kdiff3
Suggests: meld
Suggests: vim-X11
Suggests: vim-enhanced

%description
This tool search for .rpmnew, .rpmsave and .rpmorig
files and ask you what to do with them:
Keep current version, place back old version,
watch the diff or merge.

%package -n python3-rpmconf
Summary:        Python interface for %{name}
Group:          Development/Python

%description -n python3-rpmconf
Python interface for %{name}.

%package -n python3-rpmconf-doc
Summary:        Documentation of python interface for %{name}
Group:          Development/Python

%description -n python3-rpmconf-doc
Documentation generated from code of python3-rpmconf.

%package base
Summary:        Filesystem for %{name}
Group:          System/Packaging

%description base
Directory hierarchy for installation scripts,
which are handled by rpmconf.

%prep
%setup -q -n %{name}-%{name}-%{version}-%{origrel}

%build
%py3_build
docbook2man rpmconf.sgml
make -C docs html man

%install
# (ngompa) using instead of %%py3_install due to extra arg
%{__python3} setup.py install -O1 --skip-build \
    --install-scripts %{_sbindir} \
    --root %{buildroot}
install -D -m 644 rpmconf.8 %{buildroot}%{_mandir}/man8/rpmconf.8
install -D -m 644 docs/build/man/rpmconf.3 %{buildroot}%{_mandir}/man3/rpmconf.3
mkdir -p %{buildroot}%{_datadir}/rpmconf/

%if %{with tests}
%check
python3-pylint --reports=n %{buildroot}%{_sbindir}/rpmconf
python3-pylint --reports=n %{buildroot}%{python3_sitelib}/rpmconf/rpmconf.py
%endif

%files
%license LICENSE
%{_sbindir}/rpmconf
%{_mandir}/man8/rpmconf.8*

%files -n python3-rpmconf
%license LICENSE
%{python3_sitelib}/rpmconf/
%{python3_sitelib}/rpmconf-*.egg-info
%{_mandir}/man3/rpmconf.3*

%files -n python3-rpmconf-doc
%license LICENSE
%doc docs/build/html/

%files base
%dir %{_datadir}/rpmconf



%changelog
* Sun Jan 24 2016 ngompa <ngompa> 1.0.16-1.mga6
+ Revision: 926825
- Update to 1.0.16

* Mon Nov 23 2015 ngompa <ngompa> 1.0.13-2.mga6
+ Revision: 905068
- Import rpmconf into Mageia

